@@ -9,7 +9,7 @@ import interactions
 logger = logging.getLogger()
 bot = interactions.Client(
     token=os.getenv("DISCORD_TOKEN") or "",
-    intents=interactions.Intents.DEFAULT | interactions.Intents.GUILD_MESSAGE_CONTENT,
+    intents=interactions.Intents.DEFAULT,
 )
 TIMERS = {}
 
@@ -230,7 +230,7 @@ class Timer:
         if minutes > 59:
             minutes = 0
         hours = round((time - minutes * 60 - seconds) / 3600)
-        if time > 3600:
+        if time > 3569:
             return f"{hours}:{minutes:0>2} remaining"
         if time > DISPLAY_SECONDS:
             return f"{minutes} minutes remaining"
@@ -262,7 +262,12 @@ def _get_prefix(ctx: interactions.CommandContext):
     """Prefix used for log messages"""
     if ctx.guild:
         prefix = f"{ctx.guild.name}"
-        prefix += f":{ctx.channel.name}"
+        logger.debug("CTX: %s", ctx)
+        logger.debug("extras: %s", ctx._extras)
+        logger.debug("channel: %s", ctx.channel)
+        logger.debug("channel_id: %s", ctx.channel_id)
+        if ctx.channel:
+            prefix += f":{ctx.channel.name}"
     else:
         prefix = f"{ctx.author.name}"
     return prefix
@@ -292,9 +297,15 @@ def _get_prefix(ctx: interactions.CommandContext):
 )
 async def timer_start(ctx: interactions.CommandContext, hours: int, minutes: int = 0):
     """Start a timer"""
+    # channel info will miss from threads and voice channels chats
+    # see https://github.com/interactions-py/library/issues/1041
+    if ctx.channel is interactions.MISSING:
+        ctx.channel = interactions.Channel(
+            _client=ctx.client, **(await ctx.client.get_channel(ctx.channel_id))
+        )
     prefix = _get_prefix(ctx)
     # timer already running in channel
-    if ctx.channel in TIMERS:
+    if ctx.channel_id in TIMERS:
         await ctx.send(
             embeds=[
                 interactions.Embed(
@@ -360,7 +371,10 @@ async def timer_add(ctx: interactions.CommandContext, minutes: int):
     """Add time to the timer"""
     timer = TIMERS.get(ctx.channel, None)
     if not timer:
-        ctx.send("No timer running in this channel.", ephemeral=True)
+        await ctx.send(
+            "No timer running in this channel. Use `/timer start` to start one.",
+            ephemeral=True,
+        )
         return
     prefix = _get_prefix(ctx)
     time = minutes * 60
@@ -389,7 +403,10 @@ async def timer_sub(ctx: interactions.CommandContext, minutes: int):
     """Substract time from the timer"""
     timer = TIMERS.get(ctx.channel, None)
     if not timer:
-        ctx.send("No timer running in this channel.", ephemeral=True)
+        await ctx.send(
+            "No timer running in this channel. Use `/timer start` to start one.",
+            ephemeral=True,
+        )
         return
     prefix = _get_prefix(ctx)
     time = minutes * 60
@@ -405,7 +422,10 @@ async def timer_display(ctx: interactions.CommandContext):
     """Discplay the timer anew"""
     timer = TIMERS.get(ctx.channel, None)
     if not timer:
-        ctx.send("No timer running in this channel.", ephemeral=True)
+        await ctx.send(
+            "No timer running in this channel. Use `/timer start` to start one.",
+            ephemeral=True,
+        )
         return
     prefix = _get_prefix(ctx)
     await timer.refresh(resume=False)
@@ -455,7 +475,10 @@ async def _pause_timer(
 ):
     timer = TIMERS.get(ctx.channel, None)
     if not timer:
-        ctx.send("No timer running in this channel.", ephemeral=True)
+        await ctx.send(
+            "No timer running in this channel. Use `/timer start` to start one.",
+            ephemeral=True,
+        )
         return
     prefix = _get_prefix(ctx)
     await timer.pause()
@@ -474,7 +497,10 @@ async def _resume_timer(
 ):
     timer = TIMERS.get(ctx.channel, None)
     if not timer:
-        ctx.send("No timer running in this channel.", ephemeral=True)
+        await ctx.send(
+            "No timer running in this channel. Use `/timer start` to start one.",
+            ephemeral=True,
+        )
         return
     prefix = _get_prefix(ctx)
     await timer.refresh()
@@ -487,7 +513,10 @@ async def _stop_timer(
 ):
     timer = TIMERS.get(ctx.channel, None)
     if not timer:
-        ctx.send("No timer running in this channel.", ephemeral=True)
+        await ctx.send(
+            "No timer running in this channel. Use `/timer start` to start one.",
+            ephemeral=True,
+        )
         return
     await timer.stop()
     await ctx.send("Timer stopped", ephemeral=True)
